def AbstractClassWithoutFieldsNamed(cls, *excl):
	"""
	Removes unwanted fields from abstract base classes.

	Ripped off from some Gist. Feel free to submit a PR with authorship!

	Usage::
	>>> from oscar.apps.address.abstract_models import AbstractBillingAddress

	>>> from koe.meta import AbstractClassWithoutFieldsNamed as without
	>>> class BillingAddress(without(AbstractBillingAddress, 'phone_number')):
	...     pass
	"""
	if cls._meta.abstract:
		remove_fields = [f for f in cls._meta.local_fields if f.name in excl]
		for f in remove_fields:
			cls._meta.local_fields.remove(f)
		return cls
	else:
		raise Exception("Not an abstract model")


without = AbstractClassWithoutFieldsNamed



from distutils.core import setup
from setuptools import setup, find_packages

"""
Django utils to operate on abstract model classes.
"""

setup(
	name='django-abstract-utils',
	version='0.0.1',
	url='https://github.com/IlyaSemenov/django-abstract-utils',
	license='BSD',
	author='Ilya Semenov',
	author_email='ilya@semenov.co',
	description=__doc__,
	long_description=open('README.rst').read(),
	packages=['django_abstract_utils'],
	install_requires=['Django>=1.8'],
	classifiers=[],
)
